@@ -2,6 +2,7 @@ from typing import Literal
 
 WEBSOCKET_OPENED = "WEBSOCKET_OPENED"
 WEBSOCKET_SYSTEM_ONLINE = "WEBSOCKET_SYSTEM_ONLINE"
+WEBSOCKET_SYSTEM_OFFLINE = "WEBSOCKET_SYSTEM_OFFLINE"
 WEBSOCKET_SYSTEM_MAINTENANCE = "WEBSOCKET_SYSTEM_MAINTENANCE"
 WEBSOCKET_SYSTEM_CANCEL_ONLY = "WEBSOCKET_SYSTEM_CANCEL_ONLY"
 WEBSOCKET_SYSTEM_POST_ONLY = "WEBSOCKET_SYSTEM_POST_ONLY"
@@ -9,4 +10,4 @@ WEBSOCKET_SYSTEM_LIMIT_ONLY = "WEBSOCKET_SYSTEM_LIMIT_ONLY"
 WEBSOCKET_CLOSED = "WEBSOCKET_CLOSED"
 WEBSOCKET_AUTHENTICATED = "WEBSOCKET_AUTHENTICATED"
 
-Status = Literal["WEBSOCKET_OPENED", "WEBSOCKET_CLOSED", "WEBSOCKET_AUTHENTICATED", "WEBSOCKET_SYSTEM_ONLINE", "WEBSOCKET_SYSTEM_MAINTENANCE", "WEBSOCKET_SYSTEM_CANCEL_ONLY", "WEBSOCKET_SYSTEM_POST_ONLY", "WEBSOCKET_SYSTEM_LIMIT_ONLY"]
+Status = Literal["WEBSOCKET_OPENED", "WEBSOCKET_CLOSED", "WEBSOCKET_SYSTEM_OFFLINE", "WEBSOCKET_AUTHENTICATED", "WEBSOCKET_SYSTEM_ONLINE", "WEBSOCKET_SYSTEM_MAINTENANCE", "WEBSOCKET_SYSTEM_CANCEL_ONLY", "WEBSOCKET_SYSTEM_POST_ONLY", "WEBSOCKET_SYSTEM_LIMIT_ONLY"]
